"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const express_1 = __importDefault(require("express"));
const cors_1 = __importDefault(require("cors"));
const connect_loader_1 = require("@shipengine/connect-loader");
const build_api_1 = __importDefault(require("./build-api"));
const logger_1 = __importDefault(require("./utils/logger"));
async function server(port, pathToApp) {
    const server = express_1.default();
    server.use(cors_1.default());
    const appState = {
        status: "up",
        error: null,
    };
    server.get("/app-status", (_req, res) => {
        res.status(200).send(appState);
    });
    let startMessage = "";
    let sdkApp;
    try {
        sdkApp = (await connect_loader_1.loadApp(pathToApp));
        build_api_1.default(pathToApp, sdkApp, server, port);
        server.use(express_1.default.static(pathToApp, { cacheControl: false }));
        startMessage = `${sdkApp.name} is now running at http://localhost:${port}`;
    }
    catch (error) {
        const err = error;
        appState.status = "down";
        appState.error = err;
        startMessage =
            "App failed to load! Please fix the validation issues above.";
        logger_1.default.error(err.message);
    }
    server.use(function (req, res) {
        const errorMessage = sdkApp
            ? `${sdkApp.name} does not implement ${req.path}`
            : `Endpoint ${req.path} not found`;
        res.status(404).send({ message: errorMessage });
    });
    server.listen(port, () => {
        if (appState.status === "up") {
            logger_1.default.success(startMessage);
        }
        else {
            logger_1.default.warn(startMessage);
        }
    });
}
exports.default = server;
//# sourceMappingURL=server.js.map